@@ -5,7 +5,7 @@ from aws_cdk import (
 )
 from aws_cdk.core import Tags
 import boto3
-
+from aws_cdk_constructs.utils import normalize_environment_parameter
 
 def check_if_bucket_exist(s3_bucket_name, profile=None):
     aws_session = boto3.Session(profile_name=profile)
@@ -123,7 +123,8 @@ class Bucket(core.Construct):
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
-
+        environment = normalize_environment_parameter(environment)
+        
         # Apply mandatory tags
         Tags.of(self).add("ApplicationName", app_name.lower().strip())
         Tags.of(self).add("Environment", environment)
