@@ -7,6 +7,7 @@ from aws_cdk import (
     aws_kms as _kms,
 )
 from aws_cdk.core import Tags
+from aws_cdk_constructs.utils import normalize_environment_parameter
 
 engine_to_cdk_engine = {
     "legacy-aurora-mysql": _rds.DatabaseClusterEngine.aurora,
@@ -152,6 +153,7 @@ class Database(core.Construct):
         **kwargs,
     ):
         super().__init__(scope, id, **kwargs)
+        environment = normalize_environment_parameter(environment)
 
         # Apply mandatory tags
         Tags.of(self).add("ApplicationName", app_name.lower().strip())
@@ -164,7 +166,7 @@ class Database(core.Construct):
         account_id = aws_account["id"]
         vpc = _ec2.Vpc.from_lookup(self, "VPC", vpc_id=aws_account["vpc"])
 
-        is_production = environment == "Production"
+        is_production = environment == "production"
         is_not_production = not is_production
 
         is_ha = is_production
@@ -294,6 +296,7 @@ class Database(core.Construct):
                 credentials=credentials,
                 cluster_identifier=identifier_prefix + database_engine,
                 instance_identifier_base=identifier_prefix,
+                deletion_protection=is_production,
                 # No need to create instance resource, only specify the amount
                 instances=2 if is_ha else 1,
                 backup=_rds.BackupProps(
