@@ -18,6 +18,7 @@ from aws_cdk.core import Tags
 import json
 import os
 import re
+from aws_cdk_constructs.utils import normalize_environment_parameter
 
 alphanumericPattern = pattern = re.compile("\W")
 
@@ -345,6 +346,8 @@ class Microservice(core.Construct):
             aws_ec2.SecurityGroup: the provided security group
         """ 
 
+        environment = normalize_environment_parameter(environment)
+
         tg = _alb.ApplicationTargetGroup(
             self,
             id,
@@ -379,12 +382,13 @@ class Microservice(core.Construct):
         Args:
             id (str): the logical id of the newly created resource
         """
+        environment = normalize_environment_parameter(environment)
         is_production = environment == "Production"
         
         nlb = _alb.NetworkLoadBalancer(self, id + '_nlb',
             cross_zone_enabled=True,
             vpc=self.vpc,
-            deletion_protection=True if is_production else False,
+            deletion_protection=is_production,
             internet_facing=False
         )
 
@@ -422,6 +426,9 @@ class Microservice(core.Construct):
         Returns:
             aws_alb.ApplicationLoadBalancer: the newly created Load Balancer
         """ 
+        environment = normalize_environment_parameter(environment)
+        is_production = environment == "Production"
+        
         if load_balancer_name is None:
             load_balancer_name = id
         
@@ -491,6 +498,7 @@ class Microservice(core.Construct):
             internet_facing=internet_facing,
             idle_timeout=core.Duration.seconds(int(load_balancer_idle_timeout_in_seconds)),
             security_group=security_group,
+            deletion_protection=is_production
         )
 
         # Enable access from App Proxy if the Load Balancer is private
@@ -525,6 +533,7 @@ class Microservice(core.Construct):
         Returns:
             aws_ec2.SecurityGroup: the newly created security group
         """ 
+        environment = normalize_environment_parameter(environment)
         sg = _ec2.SecurityGroup(
             scope,
             id,
@@ -667,7 +676,9 @@ class Microservice(core.Construct):
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
-
+    
+        environment = normalize_environment_parameter(environment)
+        
         # Apply mandatory tags
         Tags.of(self).add("ApplicationName", app_name, apply_to_launched_instances=True,)
         Tags.of(self).add("Environment", environment, apply_to_launched_instances=True,)
@@ -850,6 +861,9 @@ class Microservice(core.Construct):
                 snapshot_id=ebs_snapshot_id,
             )
 
+            if is_production:
+                ebs.add_override("DeletionPolicy", core.RemovalPolicy.RETAIN)
+
         # ~~~~~~~~~~~~~~~~
         # Target group
         # ~~~~~~~~~~~~~~~~
